#include "tao/Services_Activate.h"

ACE_RCSID (tao,
           Services_Activate,
           "$Id: Services_Activate.cpp 69153 2005-11-02 11:03:27Z ossama $")

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO_Services_Activate::~TAO_Services_Activate (void)
{
}

TAO_END_VERSIONED_NAMESPACE_DECL
